pitchtools.TwelveToneRow
========================

.. abjad-lineage:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow

.. autoclass:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.inversion_equivalent_chromatic_interval_class_segment
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.numbered_chromatic_pitch_class_set
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.alpha
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.index
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.invert
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.multiply
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.retrograde
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.rotate
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.transpose
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__rmul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.TwelveToneRow.__str__
   :noindex:
